@@ -1,35 +1,35 @@
 RunModel_GR4J <- function(InputsModel, RunOptions, Param) {
-  
-  
+
+
   ## Initialization of variables
   NParam <- 4
   FortranOutputs <- .FortranOutputs(GR = "GR4J")$GR
-  
-  
+
+
   ## Arguments check
   if (!inherits(InputsModel, "InputsModel")) {
     stop("'InputsModel' must be of class 'InputsModel'")
-  }  
-  if (!inherits(InputsModel, "daily"      )) {
-    stop("'InputsModel' must be of class 'daily'      ")
-  }  
-  if (!inherits(InputsModel, "GR"         )) {
-    stop("'InputsModel' must be of class 'GR'         ")
-  }  
-  if (!inherits(RunOptions, "RunOptions"  )) {
-    stop("'RunOptions' must be of class 'RunOptions'  ")
-  }  
-  if (!inherits(RunOptions, "GR"          )) {
-    stop("'RunOptions' must be of class 'GR'          ")
-  }  
+  }
+  if (!inherits(InputsModel, "daily")) {
+    stop("'InputsModel' must be of class 'daily'")
+  }
+  if (!inherits(InputsModel, "GR")) {
+    stop("'InputsModel' must be of class 'GR'")
+  }
+  if (!inherits(RunOptions, "RunOptions")) {
+    stop("'RunOptions' must be of class 'RunOptions'")
+  }
+  if (!inherits(RunOptions, "GR")) {
+    stop("'RunOptions' must be of class 'GR'")
+  }
   if (!is.vector(Param) | !is.numeric(Param)) {
     stop("'Param' must be a numeric vector")
   }
   if (sum(!is.na(Param)) != NParam) {
-    stop(paste("'Param' must be a vector of length ", NParam, " and contain no NA", sep = ""))
+    stop(paste("'Param' must be a vector of length", NParam, "and contain no NA"))
   }
   Param <- as.double(Param)
-  
+
   Param_X1X3_threshold <- 1e-2
   Param_X4_threshold   <- 0.5
   if (Param[1L] < Param_X1X3_threshold) {
@@ -44,7 +44,7 @@ RunModel_GR4J <- function(InputsModel, RunOptions, Param) {
     warning(sprintf("Param[4] (X4: unit hydrograph time constant [d]) < %.2f\n X4 set to %.2f", Param_X4_threshold, Param_X4_threshold))
     Param[4L] <- Param_X4_threshold
   }
-  
+
   ## Input data preparation
   if (identical(RunOptions$IndPeriod_WarmUp, 0L)) {
     RunOptions$IndPeriod_WarmUp <- NULL
@@ -52,23 +52,24 @@ RunModel_GR4J <- function(InputsModel, RunOptions, Param) {
   IndPeriod1   <- c(RunOptions$IndPeriod_WarmUp, RunOptions$IndPeriod_Run)
   LInputSeries <- as.integer(length(IndPeriod1))
   if ("all" %in% RunOptions$Outputs_Sim) {
-    IndOutputs <- as.integer(1:length(FortranOutputs)) 
+    IndOutputs <- as.integer(1:length(FortranOutputs))
   } else {
     IndOutputs <- which(FortranOutputs %in% RunOptions$Outputs_Sim)
   }
-  ## Input data preparation      
+
+  ## Output data preparation
   IndPeriod2     <- (length(RunOptions$IndPeriod_WarmUp)+1):LInputSeries
   ExportDatesR   <- "DatesR"   %in% RunOptions$Outputs_Sim
   ExportStateEnd <- "StateEnd" %in% RunOptions$Outputs_Sim
-  
+
   ## Use of IniResLevels
   if (!is.null(RunOptions$IniResLevels)) {
     RunOptions$IniStates[1] <- RunOptions$IniResLevels[1] * Param[1] ### production store level (mm)
     RunOptions$IniStates[2] <- RunOptions$IniResLevels[2] * Param[3] ### routing store level (mm)
   }
-  
+
   ## Call GR model Fortan
-  RESULTS <- .Fortran("frun_gr4j", PACKAGE = "airGR", 
+  RESULTS <- .Fortran("frun_gr4j", PACKAGE = "airGR",
                       ## inputs
                       LInputs = LInputSeries,                             ### length of input and output series
                       InputsPrecip = InputsModel$Precip[IndPeriod1],      ### input series of total precipitation [mm/d]
@@ -80,20 +81,21 @@ RunModel_GR4J <- function(InputsModel, RunOptions, Param) {
                       NOutputs = as.integer(length(IndOutputs)),          ### number of output series
                       IndOutputs = IndOutputs,                            ### indices of output series
                       ## outputs
-                      Outputs = matrix(as.double(-999.999), nrow = LInputSeries, ncol = length(IndOutputs)), ### output series [mm]
-                      StateEnd = rep(as.double(-999.999), length(RunOptions$IniStates))                      ### state variables at the end of the model run
+                      Outputs = matrix(as.double(-99e9), nrow = LInputSeries, ncol = length(IndOutputs)), ### output series [mm or mm/d]
+                      StateEnd = rep(as.double(-99e9), length(RunOptions$IniStates))                      ### state variables at the end of the model run
   )
-  RESULTS$Outputs[ round(RESULTS$Outputs , 3) == -999.999] <- NA
-  RESULTS$StateEnd[round(RESULTS$StateEnd, 3) == -999.999] <- NA
+  RESULTS$Outputs[RESULTS$Outputs   <= -99e8] <- NA
+  RESULTS$StateEnd[RESULTS$StateEnd <= -99e8] <- NA
   if (ExportStateEnd) {
     RESULTS$StateEnd[-3L] <- ifelse(RESULTS$StateEnd[-3L] < 0, 0, RESULTS$StateEnd[-3L]) ### remove negative values except for the ExpStore location
-    RESULTS$StateEnd <- CreateIniStates(FUN_MOD = RunModel_GR4J, InputsModel = InputsModel, 
-                                        ProdStore = RESULTS$StateEnd[1L], RoutStore = RESULTS$StateEnd[2L], ExpStore = NULL, 
-                                        UH1 = RESULTS$StateEnd[(1:20)+7], UH2 = RESULTS$StateEnd[(1:40)+(7+20)], 
-                                        GCemaNeigeLayers = NULL, eTGCemaNeigeLayers = NULL, 
+    RESULTS$StateEnd <- CreateIniStates(FUN_MOD = RunModel_GR4J, InputsModel = InputsModel,
+                                        ProdStore = RESULTS$StateEnd[1L], RoutStore = RESULTS$StateEnd[2L], ExpStore = NULL,
+                                        UH1 = RESULTS$StateEnd[(1:20) + 7],
+                                        UH2 = RESULTS$StateEnd[(1:40) + (7+20)],
+                                        GCemaNeigeLayers = NULL, eTGCemaNeigeLayers = NULL,
                                         verbose = FALSE)
   }
-  
+
   ## Output data preparation
   ## OutputsModel only
   if (!ExportDatesR & !ExportStateEnd) {
@@ -102,27 +104,27 @@ RunModel_GR4J <- function(InputsModel, RunOptions, Param) {
   }
   ## DatesR and OutputsModel only
   if (ExportDatesR & !ExportStateEnd) {
-    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]), 
+    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]),
                       lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]))
     names(OutputsModel) <- c("DatesR", FortranOutputs[IndOutputs])
   }
   ## OutputsModel and StateEnd only
   if (!ExportDatesR & ExportStateEnd) {
-    OutputsModel <- c(lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]), 
+    OutputsModel <- c(lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]),
                       list(RESULTS$StateEnd))
     names(OutputsModel) <- c(FortranOutputs[IndOutputs], "StateEnd")
   }
   ## DatesR and OutputsModel and StateEnd
   if ((ExportDatesR & ExportStateEnd) | "all" %in% RunOptions$Outputs_Sim) {
-    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]), 
-                      lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]), 
+    OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]),
+                      lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]),
                       list(RESULTS$StateEnd))
     names(OutputsModel) <- c("DatesR", FortranOutputs[IndOutputs], "StateEnd")
   }
-  
+
   ## End
-  rm(RESULTS) 
+  rm(RESULTS)
   class(OutputsModel) <- c("OutputsModel", "daily", "GR")
   return(OutputsModel)
-  
+
 }
