@@ -10,23 +10,23 @@ RunModel_GR5J <- function(InputsModel, RunOptions, Param) {
   if (!inherits(InputsModel, "InputsModel")) {
     stop("'InputsModel' must be of class 'InputsModel'")
   }  
-  if (!inherits(InputsModel, "daily"      )) {
-    stop("'InputsModel' must be of class 'daily'      ")
+  if (!inherits(InputsModel, "daily")) {
+    stop("'InputsModel' must be of class 'daily'")
   }  
-  if (!inherits(InputsModel, "GR"         )) {
-    stop("'InputsModel' must be of class 'GR'         ")
+  if (!inherits(InputsModel, "GR")) {
+    stop("'InputsModel' must be of class 'GR'")
   }  
-  if (!inherits(RunOptions, "RunOptions"  )) {
-    stop("'RunOptions' must be of class 'RunOptions'  ")
+  if (!inherits(RunOptions, "RunOptions")) {
+    stop("'RunOptions' must be of class 'RunOptions'")
   }  
-  if (!inherits(RunOptions, "GR"          )) {
-    stop("'RunOptions' must be of class 'GR'          ")
+  if (!inherits(RunOptions, "GR")) {
+    stop("'RunOptions' must be of class 'GR'")
   }  
   if (!is.vector(Param) | !is.numeric(Param)) {
     stop("'Param' must be a numeric vector")
   }
   if (sum(!is.na(Param)) != NParam) {
-    stop(paste("'Param' must be a vector of length ", NParam, " and contain no NA", sep = ""))
+    stop(paste("'Param' must be a vector of length", NParam, "and contain no NA"))
   }
   Param <- as.double(Param)
   
@@ -81,16 +81,17 @@ RunModel_GR5J <- function(InputsModel, RunOptions, Param) {
                       NOutputs = as.integer(length(IndOutputs)),          ### number of output series
                       IndOutputs = IndOutputs,                            ### indices of output series
                       ## outputs
-                      Outputs = matrix(as.double(-999.999), nrow = LInputSeries, ncol = length(IndOutputs)), ### output series [mm]
-                      StateEnd = rep(as.double(-999.999), length(RunOptions$IniStates))                      ### state variables at the end of the model run
+                      Outputs = matrix(as.double(-99e9), nrow = LInputSeries, ncol = length(IndOutputs)), ### output series [mm or mm/d]
+                      StateEnd = rep(as.double(-99e9), length(RunOptions$IniStates))                      ### state variables at the end of the model run
   )
-  RESULTS$Outputs[ round(RESULTS$Outputs , 3) == -999.999] <- NA
-  RESULTS$StateEnd[round(RESULTS$StateEnd, 3) == -999.999] <- NA
+  RESULTS$Outputs[RESULTS$Outputs   <= -99e8] <- NA
+  RESULTS$StateEnd[RESULTS$StateEnd <= -99e8] <- NA
   if (ExportStateEnd) {
     RESULTS$StateEnd[-3L] <- ifelse(RESULTS$StateEnd[-3L] < 0, 0, RESULTS$StateEnd[-3L]) ### remove negative values except for the ExpStore location
     RESULTS$StateEnd <- CreateIniStates(FUN_MOD = RunModel_GR5J, InputsModel = InputsModel, 
                                         ProdStore = RESULTS$StateEnd[1L], RoutStore = RESULTS$StateEnd[2L], ExpStore = NULL, 
-                                        UH1 = NULL, UH2 = RESULTS$StateEnd[(1:40)+(7+20)], 
+                                        UH1 = NULL,
+                                        UH2 = RESULTS$StateEnd[(1:40) + (7+20)], 
                                         GCemaNeigeLayers = NULL, eTGCemaNeigeLayers = NULL, 
                                         verbose = FALSE)
   }
@@ -107,13 +108,13 @@ RunModel_GR5J <- function(InputsModel, RunOptions, Param) {
                       lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]))
     names(OutputsModel) <- c("DatesR", FortranOutputs[IndOutputs])
   }
-  ## OutputsModel and SateEnd only
+  ## OutputsModel and StateEnd only
   if (!ExportDatesR & ExportStateEnd) {
     OutputsModel <- c(lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]), 
                       list(RESULTS$StateEnd))
     names(OutputsModel) <- c(FortranOutputs[IndOutputs], "StateEnd")
   }
-  ## DatesR and OutputsModel and SateEnd
+  ## DatesR and OutputsModel and StateEnd
   if ((ExportDatesR & ExportStateEnd) | "all" %in% RunOptions$Outputs_Sim) {
     OutputsModel <- c(list(InputsModel$DatesR[RunOptions$IndPeriod_Run]), 
                       lapply(seq_len(RESULTS$NOutputs), function(i) RESULTS$Outputs[IndPeriod2, i]), 
